==> sisu_0.62.3.orig.tar.gz: sisu-0.62.3/lib/sisu/v0/db_dbi.rb <==
=begin

 * Name: SiSU

 * Description: a framework for document structuring, publishing and search

 * Author: Ralph Amissah

 * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
   2007 Ralph Amissah All Rights Reserved.

 * License: GPL 3 or later:

   SiSU, a framework for document structuring, publishing and search

   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
   2007 Ralph Amissah

   This program is free software: you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the Free
   Software Foundation, either version 3 of the License, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.

   You should have received a copy of the GNU General Public License along with
   this program. If not, see <http://www.gnu.org/licenses/>.

   If you have Internet connection, the latest version of the GPL should be
   available at these locations:
   <http://www.fsf.org/licenses/gpl.html>
   <http://www.gnu.org/copyleft/gpl.html>
   <http://www.jus.uio.no/sisu/gpl.fsf>

 * SiSU uses:
   * Standard SiSU markup syntax,
   * Standard SiSU meta-markup syntax, and the
   * Standard SiSU object citation numbering and system

 * Hompages:
   <http://www.jus.uio.no/sisu>
   <http://www.sisudoc.org>

 * Download:
   <http://www.jus.uio.no/sisu/SiSU/download.html>

 * Ralph Amissah
   <ralph@amissah.com>
   <ralph.amissah@gmail.com>

 ** Description: modules shared by the different db types, dbi, postgresql,
    sqlite

=end
module  SiSU_DB_DBI
  require "#{SiSU_lib}/db_columns"
  require "#{SiSU_lib}/db_tests"
  require "#{SiSU_lib}/db_create"
  require "#{SiSU_lib}/db_select"
  require "#{SiSU_lib}/db_indexes"
  require "#{SiSU_lib}/db_drop"
  require "#{SiSU_lib}/db_remove"
  require "#{SiSU_lib}/db_load_tuple"
  require "#{SiSU_lib}/db_import"
  class Column_size < SiSU_DB_columns::Column_size
  end
  class Test < SiSU_DB_tests::Test
  end
  class Create <SiSU_DB_create::Create #<SiSU_DB::Column_size
  end
  class Case <SiSU_DB_select::Case
  end
  class Index <SiSU_DB_index::Index                                           # create documents Indexes def initialize(opt,conn='',sql_type='')
  end
  class Drop <SiSU_DB_drop::Drop
  end
  class Remove <SiSU_DB_remove::Remove
  end
  class Load_documents <SiSU_DB_tuple::Load_documents                                  #% main database populate/update
  end
  class Load_metadata <SiSU_DB_tuple::Load_metadata                                    #% update metadata
  end
  class Load_urls <SiSU_DB_tuple::Load_urls                                            #% update urls
  end
  class Import <SiSU_DB_import::Import #<SiSU_DB::Column_size                  #% main
  end
end
__END__

==> sisu_0.68.0.orig.tar.gz: sisu-0.68.0/lib/sisu/v0/db_dbi.rb <==
# coding: utf-8
=begin

 * Name: SiSU

 * Description: a framework for document structuring, publishing and search

 * Author: Ralph Amissah

 * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
   2007, 2008 Ralph Amissah All Rights Reserved.

 * License: GPL 3 or later:

   SiSU, a framework for document structuring, publishing and search

   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
   2007, 2008 Ralph Amissah

   This program is free software: you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the Free
   Software Foundation, either version 3 of the License, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.

   You should have received a copy of the GNU General Public License along with
   this program. If not, see <http://www.gnu.org/licenses/>.

   If you have Internet connection, the latest version of the GPL should be
   available at these locations:
   <http://www.fsf.org/licensing/licenses/gpl.html>
   <http://www.gnu.org/licenses/gpl.html>

   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>

 * SiSU uses:
   * Standard SiSU markup syntax,
   * Standard SiSU meta-markup syntax, and the
   * Standard SiSU object citation numbering and system

 * Hompages:
   <http://www.jus.uio.no/sisu>
   <http://www.sisudoc.org>

 * Download:
   <http://www.jus.uio.no/sisu/SiSU/download.html>

 * Ralph Amissah
   <ralph@amissah.com>
   <ralph.amissah@gmail.com>

 ** Description: modules shared by the different db types, dbi, postgresql,
    sqlite

=end
module  SiSU_DB_DBI
  require "#{SiSU_lib}/db_columns"
  require "#{SiSU_lib}/db_tests"
  require "#{SiSU_lib}/db_create"
  require "#{SiSU_lib}/db_select"
  require "#{SiSU_lib}/db_indexes"
  require "#{SiSU_lib}/db_drop"
  require "#{SiSU_lib}/db_remove"
  require "#{SiSU_lib}/db_load_tuple"
  require "#{SiSU_lib}/db_import"
  class Column_size < SiSU_DB_columns::Column_size
  end
  class Test < SiSU_DB_tests::Test
  end
  class Create <SiSU_DB_create::Create #<SiSU_DB::Column_size
  end
  class Case <SiSU_DB_select::Case
  end
  class Index <SiSU_DB_index::Index                                           # create documents Indexes def initialize(opt,conn='',sql_type='')
  end
  class Drop <SiSU_DB_drop::Drop
  end
  class Remove <SiSU_DB_remove::Remove
  end
  class Load_documents <SiSU_DB_tuple::Load_documents                                  #% main database populate/update
  end
  class Load_metadata <SiSU_DB_tuple::Load_metadata                                    #% update metadata
  end
  class Load_urls <SiSU_DB_tuple::Load_urls                                            #% update urls
  end
  class Import <SiSU_DB_import::Import #<SiSU_DB::Column_size                  #% main
  end
end
__END__
